@@ -12,10 +12,11 @@ The ActionBar widget is like Android's `ActionBar
 are stacked horizontally. When the area becomes to small, widgets are moved
 into the :class:`ActionOverflow` area.
 
-An :class:`ActionBar` contains an :class:`ActionView` with various
+An :class:`ActionBar` must contain an :class:`ActionView` with various
 :class:`ContextualActionViews <kivy.uix.actionbar.ContextualActionView>`.
-An :class:`ActionView` will contain an :class:`ActionPrevious` having title,
-app_icon and previous_icon properties. An :class:`ActionView` will contain
+An :class:`ActionView` must contain a child :class:`ActionPrevious` which may
+have title, app_icon and previous_icon properties. :class:`ActionView` children
+must be
 subclasses of :class:`ActionItems <ActionItem>`. Some predefined ones include
 an :class:`ActionButton`, an :class:`ActionToggleButton`, an
 :class:`ActionCheck`, an :class:`ActionSeparator` and an :class:`ActionGroup`.
@@ -48,7 +49,7 @@ from kivy.uix.spinner import Spinner
 from kivy.uix.label import Label
 from kivy.config import Config
 from kivy.properties import ObjectProperty, NumericProperty, BooleanProperty, \
-    StringProperty, ListProperty, OptionProperty, AliasProperty
+    StringProperty, ListProperty, OptionProperty, AliasProperty, ColorProperty
 from kivy.metrics import sp
 from kivy.lang import Builder
 from functools import partial
@@ -84,7 +85,9 @@ class ActionItem(object):
     def get_pack_width(self):
         return max(self.minimum_width, self.width)
 
-    pack_width = AliasProperty(get_pack_width, bind=('minimum_width', 'width'))
+    pack_width = AliasProperty(get_pack_width,
+                               bind=('minimum_width', 'width'),
+                               cache=True)
     '''
     (read-only) The actual width to use when packing the items. Equal to the
     greater of minimum_width and width.
@@ -149,7 +152,7 @@ class ActionButton(Button, ActionItem):
     and takes care of the padding between elements.
 
     You don't have much control over these properties, so if you want to
-    customize it's appearance, we suggest you create you own button
+    customize its appearance, we suggest you create you own button
     representation. You can do this by creating a class that subclasses an
     existing widget and an :class:`ActionItem`::
 
@@ -209,12 +212,16 @@ class ActionPrevious(BoxLayout, ActionItem):
     and defaults to 0.
     '''
 
-    color = ListProperty([1, 1, 1, 1])
+    color = ColorProperty([1, 1, 1, 1])
     '''
     Text color, in the format (r, g, b, a)
 
-    :attr:`color` is a :class:`~kivy.properties.ListProperty` and defaults
+    :attr:`color` is a :class:`~kivy.properties.ColorProperty` and defaults
     to [1, 1, 1, 1].
+
+    .. versionchanged:: 2.0.0
+        Changed from :class:`~kivy.properties.ListProperty` to
+        :class:`~kivy.properties.ColorProperty`.
     '''
 
     previous_image = StringProperty(
@@ -446,17 +453,21 @@ class ActionGroup(ActionItem, Button):
             # auto_dismiss applies to touching outside of the DropDown
             item.bind(on_release=ddn.dismiss)
 
-    def add_widget(self, item):
+    def add_widget(self, widget, *args, **kwargs):
+        '''
+        .. versionchanged:: 2.1.0
+            Renamed argument `item` to `widget`.
+        '''
         # if adding ActionSeparator ('normal' mode,
         # everything visible), add it to the parent
-        if isinstance(item, ActionSeparator):
-            super(ActionGroup, self).add_widget(item)
+        if isinstance(widget, ActionSeparator):
+            super(ActionGroup, self).add_widget(widget, *args, **kwargs)
             return
 
-        if not isinstance(item, ActionItem):
+        if not isinstance(widget, ActionItem):
             raise ActionBarException('ActionGroup only accepts ActionItem')
 
-        self.list_action_item.append(item)
+        self.list_action_item.append(widget)
 
     def show_group(self):
         # 'normal' mode, items can fit to the view
@@ -465,8 +476,8 @@ class ActionGroup(ActionItem, Button):
             item.inside_group = True
             self._dropdown.add_widget(item)
 
-    def clear_widgets(self):
-        self._dropdown.clear_widgets()
+    def clear_widgets(self, *args, **kwargs):
+        self._dropdown.clear_widgets(*args, **kwargs)
 
 
 class ActionOverflow(ActionGroup):
@@ -483,24 +494,28 @@ class ActionOverflow(ActionGroup):
     and defaults to 'atlas://data/images/defaulttheme/overflow'.
     '''
 
-    def add_widget(self, action_item, index=0):
-        if action_item is None:
+    def add_widget(self, widget, index=0, *args, **kwargs):
+        '''
+        .. versionchanged:: 2.1.0
+             Renamed argument `action_item` to `widget`.
+        '''
+        if widget is None:
             return
 
-        if isinstance(action_item, ActionSeparator):
+        if isinstance(widget, ActionSeparator):
             return
 
-        if not isinstance(action_item, ActionItem):
+        if not isinstance(widget, ActionItem):
             raise ActionBarException('ActionView only accepts ActionItem'
-                                     ' (got {!r}'.format(action_item))
+                                     ' (got {!r}'.format(widget))
 
         else:
             if index == 0:
                 index = len(self._list_overflow_items)
-            self._list_overflow_items.insert(index, action_item)
+            self._list_overflow_items.insert(index, widget)
 
     def show_default_items(self, parent):
-        # display overflow and it's items if widget's directly added to it
+        # display overflow and its items if widget's directly added to it
         if self._list_overflow_items == []:
             return
         self.show_group()
@@ -520,12 +535,16 @@ class ActionView(BoxLayout):
     and defaults to None.
     '''
 
-    background_color = ListProperty([1, 1, 1, 1])
+    background_color = ColorProperty([1, 1, 1, 1])
     '''
     Background color in the format (r, g, b, a).
 
-    :attr:`background_color` is a :class:`~kivy.properties.ListProperty` and
+    :attr:`background_color` is a :class:`~kivy.properties.ColorProperty` and
     defaults to [1, 1, 1, 1].
+
+    .. versionchanged:: 2.0.0
+        Changed from :class:`~kivy.properties.ListProperty` to
+        :class:`~kivy.properties.ColorProperty`.
     '''
 
     background_image = StringProperty(
@@ -565,30 +584,34 @@ class ActionView(BoxLayout):
     def on_action_previous(self, instance, value):
         self._list_action_items.insert(0, value)
 
-    def add_widget(self, action_item, index=0):
-        if action_item is None:
+    def add_widget(self, widget, index=0, *args, **kwargs):
+        '''
+        .. versionchanged:: 2.1.0
+            Renamed argument `action_item` to `widget`.
+        '''
+        if widget is None:
             return
 
-        if not isinstance(action_item, ActionItem):
+        if not isinstance(widget, ActionItem):
             raise ActionBarException('ActionView only accepts ActionItem'
-                                     ' (got {!r}'.format(action_item))
+                                     ' (got {!r}'.format(widget))
 
-        elif isinstance(action_item, ActionOverflow):
-            self.overflow_group = action_item
-            action_item.use_separator = self.use_separator
+        elif isinstance(widget, ActionOverflow):
+            self.overflow_group = widget
+            widget.use_separator = self.use_separator
 
-        elif isinstance(action_item, ActionGroup):
-            self._list_action_group.append(action_item)
-            action_item.use_separator = self.use_separator
+        elif isinstance(widget, ActionGroup):
+            self._list_action_group.append(widget)
+            widget.use_separator = self.use_separator
 
-        elif isinstance(action_item, ActionPrevious):
-            self.action_previous = action_item
+        elif isinstance(widget, ActionPrevious):
+            self.action_previous = widget
 
         else:
-            super(ActionView, self).add_widget(action_item, index)
+            super(ActionView, self).add_widget(widget, index, *args, **kwargs)
             if index == 0:
                 index = len(self._list_action_items)
-            self._list_action_items.insert(index, action_item)
+            self._list_action_items.insert(index, widget)
 
     def on_use_separator(self, instance, value):
         for group in self._list_action_group:
@@ -596,8 +619,8 @@ class ActionView(BoxLayout):
         if self.overflow_group:
             self.overflow_group.use_separator = value
 
-    def remove_widget(self, widget):
-        super(ActionView, self).remove_widget(widget)
+    def remove_widget(self, widget, *args, **kwargs):
+        super(ActionView, self).remove_widget(widget, *args, **kwargs)
         if isinstance(widget, ActionOverflow):
             for item in widget.list_action_item:
                 if item in self._list_action_items:
@@ -770,7 +793,7 @@ class ActionBar(BoxLayout):
     '''
     ActionBar class, which acts as the main container for an
     :class:`ActionView` instance. The ActionBar determines the overall
-    styling aspects of the bar. :class:`ActionItem`\s are not added to
+    styling aspects of the bar. :class:`ActionItem`\\s are not added to
     this class directly, but to the contained :class:`ActionView` instance.
 
     :Events:
@@ -788,12 +811,16 @@ class ActionBar(BoxLayout):
     defaults to None or the last ActionView instance added to the ActionBar.
     '''
 
-    background_color = ListProperty([1, 1, 1, 1])
+    background_color = ColorProperty([1, 1, 1, 1])
     '''
     Background color, in the format (r, g, b, a).
 
-    :attr:`background_color` is a :class:`~kivy.properties.ListProperty` and
+    :attr:`background_color` is a :class:`~kivy.properties.ColorProperty` and
     defaults to [1, 1, 1, 1].
+
+    .. versionchanged:: 2.0.0
+        Changed from :class:`~kivy.properties.ListProperty` to
+        :class:`~kivy.properties.ColorProperty`.
     '''
 
     background_image = StringProperty(
@@ -821,18 +848,22 @@ class ActionBar(BoxLayout):
         self._stack_cont_action_view = []
         self._emit_previous = partial(self.dispatch, 'on_previous')
 
-    def add_widget(self, view):
-        if isinstance(view, ContextualActionView):
-            self._stack_cont_action_view.append(view)
-            if view.action_previous is not None:
-                view.action_previous.unbind(on_release=self._emit_previous)
-                view.action_previous.bind(on_release=self._emit_previous)
+    def add_widget(self, widget, *args, **kwargs):
+        '''
+        .. versionchanged:: 2.1.0
+            Renamed argument `view` to `widget`.
+        '''
+        if isinstance(widget, ContextualActionView):
+            self._stack_cont_action_view.append(widget)
+            if widget.action_previous is not None:
+                widget.action_previous.unbind(on_release=self._emit_previous)
+                widget.action_previous.bind(on_release=self._emit_previous)
             self.clear_widgets()
-            super(ActionBar, self).add_widget(view)
+            super(ActionBar, self).add_widget(widget, *args, **kwargs)
 
-        elif isinstance(view, ActionView):
-            self.action_view = view
-            super(ActionBar, self).add_widget(view)
+        elif isinstance(widget, ActionView):
+            self.action_view = widget
+            super(ActionBar, self).add_widget(widget, *args, **kwargs)
 
         else:
             raise ActionBarException(
