@@ -115,7 +115,7 @@ from kivy.clock import Clock
 from kivy.uix.label import Label
 from kivy.uix.widget import Widget
 from kivy.properties import BooleanProperty, ListProperty, ObjectProperty, \
-    AliasProperty, NumericProperty, ReferenceListProperty
+    AliasProperty, NumericProperty, ReferenceListProperty, ColorProperty
 
 
 class TreeViewException(Exception):
@@ -214,11 +214,15 @@ class TreeViewNode(object):
     to -1.
     '''
 
-    color_selected = ListProperty([.3, .3, .3, 1.])
+    color_selected = ColorProperty([.3, .3, .3, 1.])
     '''Background color of the node when the node is selected.
 
-    :attr:`color_selected` is a :class:`~kivy.properties.ListProperty` and
+    :attr:`color_selected` is a :class:`~kivy.properties.ColorProperty` and
     defaults to [.1, .1, .1, 1].
+
+    .. versionchanged:: 2.0.0
+        Changed from :class:`~kivy.properties.ListProperty` to
+        :class:`~kivy.properties.ColorProperty`.
     '''
 
     odd = BooleanProperty(False)
@@ -229,18 +233,26 @@ class TreeViewNode(object):
     False.
     '''
 
-    odd_color = ListProperty([1., 1., 1., .0])
+    odd_color = ColorProperty([1., 1., 1., .0])
     '''Background color of odd nodes when the node is not selected.
 
-    :attr:`odd_color` is a :class:`~kivy.properties.ListProperty` and defaults
+    :attr:`odd_color` is a :class:`~kivy.properties.ColorProperty` and defaults
     to [1., 1., 1., 0.].
+
+    .. versionchanged:: 2.0.0
+        Changed from :class:`~kivy.properties.ListProperty` to
+        :class:`~kivy.properties.ColorProperty`.
     '''
 
-    even_color = ListProperty([0.5, 0.5, 0.5, 0.1])
+    even_color = ColorProperty([0.5, 0.5, 0.5, 0.1])
     '''Background color of even nodes when the node is not selected.
 
-    :attr:`bg_color` is a :class:`~kivy.properties.ListProperty` ans defaults
+    :attr:`bg_color` is a :class:`~kivy.properties.ColorProperty` and defaults
     to [.5, .5, .5, .1].
+
+    .. versionchanged:: 2.0.0
+        Changed from :class:`~kivy.properties.ListProperty` to
+        :class:`~kivy.properties.ColorProperty`.
     '''
 
 
